@@ -71,6 +71,7 @@ Puppet::Type.type(:glance_image).provide(
     opts << "--min-ram=#{@resource[:min_ram]}" if @resource[:min_ram]
     opts << "--id=#{@resource[:id]}" if @resource[:id]
     opts << props_to_s(@resource[:properties]) if @resource[:properties]
+    opts << "--tag=#{@resource[:image_tag]}" if @resource[:image_tag]
     opts << location
 
     begin
@@ -122,6 +123,10 @@ Puppet::Type.type(:glance_image).provide(
     @property_flush[:properties] = value
   end
 
+  def image_tag=(value)
+    @property_flush[:image_tag] = value
+  end
+
   def id=(id)
     fail('id for existing images can not be modified')
   end
@@ -130,7 +135,7 @@ Puppet::Type.type(:glance_image).provide(
     list = request('image', 'list', '--long')
     list.collect do |image|
       attrs = request('image', 'show', image[:id])
-      properties = Hash[attrs[:properties].scan(/(\S+)='([^']*)'/)] rescue nil
+      properties = parsestring(attrs[:properties]) rescue nil
       new(
         :ensure           => :present,
         :name             => attrs[:name],
@@ -140,7 +145,8 @@ Puppet::Type.type(:glance_image).provide(
         :disk_format      => attrs[:disk_format],
         :min_disk         => attrs[:min_disk],
         :min_ram          => attrs[:min_ram],
-        :properties       => exclude_readonly_props(properties)
+        :properties       => exclude_owner_specified_props(exclude_readonly_props(properties)),
+        :image_tag        => attrs[:image_tag]
       )
     end
   end
@@ -165,6 +171,7 @@ Puppet::Type.type(:glance_image).provide(
       (opts << "--min-ram=#{@property_flush[:min_ram]}") if @property_flush[:min_ram]
       (opts << "--min-disk=#{@property_flush[:min_disk]}") if @property_flush[:min_disk]
       (opts << props_to_s(@property_flush[:properties])) if @property_flush[:properties]
+      (opts << "--tag=#{@property_flush[:image_tag]}") if @property_flush[:image_tag]
 
       self.class.request('image', 'set', opts)
       @property_flush.clear
@@ -177,15 +184,41 @@ Puppet::Type.type(:glance_image).provide(
     if props == nil
       return nil
     end
-    hidden = ['os_hash_algo', 'os_hash_value', 'os_hidden']
+    hidden = ['os_hash_algo', 'os_hash_value', 'os_hidden', 'self']
     rv = props.select { |k, v| not hidden.include?(k) }
     return rv
   end
 
+  def self.exclude_owner_specified_props(props)
+    if props == nil
+      return nil
+    end
+    rv = props.select { |k, v| not k.start_with?('owner_specified.') }
+    return rv
+  end
+
   def props_to_s(props)
     hidden = ['os_hash_algo', 'os_hash_value', 'os_hidden']
     props.flat_map{ |k, v|
       ['--property', "#{k}=#{v}"] unless hidden.include?(k)
     }.compact
   end
+
+  def self.string2hash(input)
+    return Hash[input.scan(/(\S+)='([^']*)'/)]
+  end
+
+  def self.pythondict2hash(input)
+    return JSON.parse(input.gsub(/u'(\w*)'/, '"\1"').gsub(/'/, '"').gsub(/False/,'false').gsub(/True/,'true'))
+  end
+
+  def self.parsestring(input)
+    if input[0] == '{'
+      # 4.0.0+ output, python dict
+      return self.pythondict2hash(input)
+    else
+      # Pre-4.0.0 output, key=value
+      return self.string2hash(input)
+    end
+  end
 end
