@@ -46,7 +46,7 @@ describe 'glance::backend::multistore::swift' do
         is_expected.to contain_glance_api_config('swift/swift_store_create_container_on_put').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('swift/swift_store_endpoint_type').with_value('internalURL')
         is_expected.to contain_glance_api_config('swift/swift_store_region').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_glance_api_config('swift/swift_store_config_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_api_config('swift/swift_store_config_file').with_value('/etc/glance/glance-swift.conf')
         is_expected.to contain_glance_api_config('swift/default_swift_reference').with_value('ref1')
         is_expected.to contain_glance_swift_config('ref1/key').with_value('key')
         is_expected.to contain_glance_swift_config('ref1/user').with_value('user')
@@ -73,7 +73,7 @@ describe 'glance::backend::multistore::swift' do
           :swift_store_create_container_on_put => true,
           :swift_store_endpoint_type           => 'publicURL',
           :swift_store_region                  => 'RegionTwo',
-          :swift_store_config_file             => '/etc/glance/glance-swift.conf',
+          :swift_store_config_file             => '/etc/glance/glance-swift2.conf',
           :default_swift_reference             => 'swift_creds',
         }
       end
@@ -86,7 +86,7 @@ describe 'glance::backend::multistore::swift' do
         is_expected.to contain_glance_api_config('swift/swift_store_large_object_chunk_size').with_value('50')
         is_expected.to contain_glance_api_config('swift/swift_store_endpoint_type').with_value('publicURL')
         is_expected.to contain_glance_api_config('swift/swift_store_region').with_value('RegionTwo')
-        is_expected.to contain_glance_api_config('swift/swift_store_config_file').with_value('/etc/glance/glance-swift.conf')
+        is_expected.to contain_glance_api_config('swift/swift_store_config_file').with_value('/etc/glance/glance-swift2.conf')
         is_expected.to contain_glance_api_config('swift/default_swift_reference').with_value('swift_creds')
         is_expected.to contain_glance_swift_config('swift_creds/key').with_value('key2')
         is_expected.to contain_glance_swift_config('swift_creds/user').with_value('user2')
